@@ -10,7 +10,7 @@ from .imagesRef.Filter import Filter
 from .imagesRef.DatabaserOperator import databaseOperator as dbOp
 import os
 
-def run(proj_absPath, oriDomain, database, tableNameList):
+def run(proj_absPath, oriDomain, database, tableNameList, maskFilt=False):
     updateTime = tools.getCurDate()
     '''
     oriDomain = 'huxiu'
@@ -37,21 +37,32 @@ def run(proj_absPath, oriDomain, database, tableNameList):
     # 从数据库获取图片链接 下载图片
     print("从数据库获取图片链接")
     dbOperator = dbOp.dbOperator(database)
+    # 上传过的图片去重
+    picList_posted_ = dbOperator.getAllDataFromDB("SELECT `origin_pic_path` FROM `postedurldatabase`.`tb_contentimgs_posted`")
+    picList_posted = []
+    for item in picList_posted_:
+        picList_posted.append(item[0])
+    print(picList_posted)
     print("下面开始下载图片")
     for table in tableNameList:
         sql = "SELECT `id`,`origin_pic_path` FROM `" + table + "`;"
         imgUrlPathList = dbOperator.getAllDataFromDB(sql)
         print("数据表为 ", table, "获得图片链接数量： ", len(imgUrlPathList))
         for imgUrl in imgUrlPathList:
+            if (imgUrl[1] in picList_posted):
+                continue
             imgName = table + "_" + str(imgUrl[0])
             tools.downimg(urlpath=imgUrl[1], imgname=imgName, dstDirPath=setting["imgsCrawledDir"])
+            insert_SQL = "INSERT INTO `postedurldatabase`.`tb_contentimgs_posted` (`origin_pic_path`) VALUES (\'{}\');".format(
+                imgUrl[1])
+            dbOperator.insertData2DB(insert_SQL)
 
     print("图片下载完成")
 
     # 对爬取下来的图片进行处理 - 识别重命名、过滤、水印的识别及裁切 处理完后放在路径  ./assets/imgsCleanedDir 下
     # 2 重命名
-    # classifier = Classifier.imgsClassifier(crawledDirPath=setting['imgsCrawledDir'], savedDirPath=setting['imgsReconizedDir'])
-    # classifier.run()
+    classifier = Classifier.imgsClassifier(crawledDirPath=setting['imgsCrawledDir'], savedDirPath=setting['imgsReconizedDir'])
+    classifier.run()
 
     # 3 过滤 (关键词过滤、空文件过滤、水印识别及处理）
     print("下面开始过滤操作")
@@ -59,15 +70,17 @@ def run(proj_absPath, oriDomain, database, tableNameList):
         imgsDontHasWaterMaskDir=setting['imgsDirDontHasWaterMask'],
         imgDirHasWaterMask=setting['imgsDirHasWaterMask'],
         imgCleanedStep1=setting['imgsCleanedDir'],
-        # dirOriPath=setting['imgsReconizedDir']
-        dirOriPath=setting['imgsCrawledDir']
+        dirOriPath=setting['imgsReconizedDir']
+        # dirOriPath=setting['imgsCrawledDir']
     )
-    filter.run()  # 这里再做一下优化
+    if(maskFilt):
+        filter.run()  # 这里再做一下优化
+    else:
+        filter.run_nomaskOp()
     print("过滤操作完成")
 
     # 4 创建图片发送的poster 传送处理完成的图片
     # 传送内容图
-    # imgposter0 = Poster.ImgPoster(imgDirPath=setting['imgsCleanedDir'])
-    # imgposter0.updateImgs()
-
+    imgposter0 = Poster.ImgPoster(imgDirPath=setting['imgsCleanedDir'])
+    imgposter0.updateImgs()
     globalTools.finishTask()
